==> seedsui-react-5.5.92.tgz: package/lib/Jcrop/原代码/widget.js <==
function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { var _i = arr == null ? null : typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"]; if (_i == null) return; var _arr = []; var _n = true; var _d = false; var _s, _e; try { for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); Object.defineProperty(Constructor, "prototype", { writable: false }); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); Object.defineProperty(subClass, "prototype", { writable: false }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf ? Object.setPrototypeOf.bind() : function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf.bind() : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

import extend from "./util/extend";
import Handle from "./handle";
import Defaults from "./defaults";
import Dragger from "./dragger";
import Rect from "./rect";
import Sticker from "./sticker";
import ConfObj from "./confobj";
import Keyboard from "./keyboard";
import Animate from "./animate";

var Widget = /*#__PURE__*/function (_ConfObj) {
  _inherits(Widget, _ConfObj);

  var _super = _createSuper(Widget);

  function Widget(el) {
    var _this;

    var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

    _classCallCheck(this, Widget);

    _this = _super.call(this, el, options);
    _this.pos = Rect.from(_this.el);

    _this.init();

    return _this;
  }

  _createClass(Widget, [{
    key: "init",
    value: function init() {
      this.createHandles();
      this.createMover();
      this.attachFocus();
      Keyboard.attach(this);
      return this;
    }
  }, {
    key: "initOptions",
    value: function initOptions() {
      var _this2 = this;

      this._optconf['aspectRatio'] = function (ar) {
        var p = _this2.pos;
        _this2.aspect = ar || null;

        if (_this2.aspect && p) {
          var _Rect$getMax = Rect.getMax(p.w, p.h, ar),
              _Rect$getMax2 = _slicedToArray(_Rect$getMax, 2),
              w = _Rect$getMax2[0],
              h = _Rect$getMax2[1];

          _this2.render(Rect.fromPoint([p.x, p.y], w, h));
        }
      };
    }
  }, {
    key: "attachToStage",
    value: function attachToStage(stage) {
      this.stage = stage;
      this.emit('crop.attach');
    }
  }, {
    key: "attachFocus",
    value: function attachFocus() {
      var _this3 = this;

      this.el.addEventListener('focus', function (e) {
        _this3.stage.activate(_this3);

        _this3.emit('crop.update');
      }, false);
    }
  }, {
    key: "animate",
    value: function animate(rect, frames, efunc) {
      var _this4 = this;

      var t = this;
      efunc = efunc || t.options.animateEasingFunction || 'swing';
      frames = frames || t.options.animateFrames || 30;
      return Animate(t.el, t.pos, rect, function (r) {
        return t.render(r.normalize());
      }, frames, efunc).then(function () {
        return _this4.emit('crop.change');
      });
    }
  }, {
    key: "createMover",
    value: function createMover() {
      var _this5 = this;

      var w, h;
      this.pos = Rect.from(this.el);
      var stick;
      Dragger(this.el, function () {
        var pe = _this5.el.parentElement;
        if (!_this5.stage.enabled) return false;
        var _ref = [pe.offsetWidth, pe.offsetHeight];
        w = _ref[0];
        h = _ref[1];
        stick = Rect.from(_this5.el);

        _this5.el.focus();

        _this5.stage.activate(_this5);

        return true;
      }, function (x, y) {
        _this5.pos.x = stick.x + x;
        _this5.pos.y = stick.y + y;

        _this5.render(_this5.pos.rebound(w, h));
      }, function () {
        _this5.emit('crop.change');
      });
    }
  }, {
    key: "nudge",
    value: function nudge() {
      var x = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 0;
      var y = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
      var pe = this.el.parentElement;
      var _ref2 = [pe.offsetWidth, pe.offsetHeight],
          w = _ref2[0],
          h = _ref2[1];
      if (x) this.pos.x += x;
      if (y) this.pos.y += y;
      this.render(this.pos.rebound(w, h));
      this.emit('crop.change');
    }
  }, {
    key: "createHandles",
    value: function createHandles() {
      var _this6 = this;

      this.options.handles.forEach(function (c) {
        var handle = Handle.create('jcrop-handle ' + c);
        handle.appendTo(_this6.el);
        var stick;
        Dragger(handle.el, function () {
          if (!_this6.stage.enabled) return false;
          var pe = _this6.el.parentElement;
          var w = pe.offsetWidth;
          var h = pe.offsetHeight;
          stick = Sticker.create(Rect.from(_this6.el), w, h, c);
          if (_this6.aspect) stick.aspect = _this6.aspect;

          _this6.el.focus();

          _this6.emit('crop.active');

          return true;
        }, function (x, y) {
          return _this6.render(stick.move(x, y));
        }, function () {
          _this6.emit('crop.change');
        });
      });
      return this;
    }
  }, {
    key: "isActive",
    value: function isActive() {
      return this.stage && this.stage.active === this;
    }
  }, {
    key: "render",
    value: function render(r) {
      r = r || this.pos;
      this.el.style.top = Math.round(r.y) + 'px';
      this.el.style.left = Math.round(r.x) + 'px';
      this.el.style.width = Math.round(r.w) + 'px';
      this.el.style.height = Math.round(r.h) + 'px';
      this.pos = r;
      this.emit('crop.update');
      return this;
    }
  }, {
    key: "doneDragging",
    value: function doneDragging() {
      this.pos = Rect.from(this.el);
    }
  }]);

  return Widget;
}(ConfObj);

Widget.create = function () {
  var options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var el = document.createElement('div');
  var opts = extend({}, Defaults, options);
  el.setAttribute('tabindex', '0');
  el.className = opts.cropperClass || 'jcrop-widget';
  return new (options.widgetConstructor || Widget)(el, opts);
};

export default Widget;

==> seedsui-react-5.6.70.tgz: package/lib/Jcrop/原代码/widget.js <==
function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }
function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }
function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
function _iterableToArrayLimit(arr, i) { var _i = null == arr ? null : "undefined" != typeof Symbol && arr[Symbol.iterator] || arr["@@iterator"]; if (null != _i) { var _s, _e, _x, _r, _arr = [], _n = !0, _d = !1; try { if (_x = (_i = _i.call(arr)).next, 0 === i) { if (Object(_i) !== _i) return; _n = !1; } else for (; !(_n = (_s = _x.call(_i)).done) && (_arr.push(_s.value), _arr.length !== i); _n = !0); } catch (err) { _d = !0, _e = err; } finally { try { if (!_n && null != _i.return && (_r = _i.return(), Object(_r) !== _r)) return; } finally { if (_d) throw _e; } } return _arr; } }
function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }
function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, _toPropertyKey(descriptor.key), descriptor); } }
function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); Object.defineProperty(Constructor, "prototype", { writable: false }); return Constructor; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return _typeof(key) === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (_typeof(input) !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (_typeof(res) !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }
function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); Object.defineProperty(subClass, "prototype", { writable: false }); if (superClass) _setPrototypeOf(subClass, superClass); }
function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf ? Object.setPrototypeOf.bind() : function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }
function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }
function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }
function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }
function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }
function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf.bind() : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }
import extend from "./util/extend";
import Handle from "./handle";
import Defaults from "./defaults";
import Dragger from "./dragger";
import Rect from "./rect";
import Sticker from "./sticker";
import ConfObj from "./confobj";
import Keyboard from "./keyboard";
import Animate from "./animate";
var Widget = /*#__PURE__*/function (_ConfObj) {
  _inherits(Widget, _ConfObj);
  var _super = _createSuper(Widget);
  function Widget(el) {
    var _this;
    var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
    _classCallCheck(this, Widget);
    _this = _super.call(this, el, options);
    _this.pos = Rect.from(_this.el);
    _this.init();
    return _this;
  }
  _createClass(Widget, [{
    key: "init",
    value: function init() {
      this.createHandles();
      this.createMover();
      this.attachFocus();
      Keyboard.attach(this);
      return this;
    }
  }, {
    key: "initOptions",
    value: function initOptions() {
      var _this2 = this;
      this._optconf['aspectRatio'] = function (ar) {
        var p = _this2.pos;
        _this2.aspect = ar || null;
        if (_this2.aspect && p) {
          var _Rect$getMax = Rect.getMax(p.w, p.h, ar),
            _Rect$getMax2 = _slicedToArray(_Rect$getMax, 2),
            w = _Rect$getMax2[0],
            h = _Rect$getMax2[1];
          _this2.render(Rect.fromPoint([p.x, p.y], w, h));
        }
      };
    }
  }, {
    key: "attachToStage",
    value: function attachToStage(stage) {
      this.stage = stage;
      this.emit('crop.attach');
    }
  }, {
    key: "attachFocus",
    value: function attachFocus() {
      var _this3 = this;
      this.el.addEventListener('focus', function (e) {
        _this3.stage.activate(_this3);
        _this3.emit('crop.update');
      }, false);
    }
  }, {
    key: "animate",
    value: function animate(rect, frames, efunc) {
      var _this4 = this;
      var t = this;
      efunc = efunc || t.options.animateEasingFunction || 'swing';
      frames = frames || t.options.animateFrames || 30;
      return Animate(t.el, t.pos, rect, function (r) {
        return t.render(r.normalize());
      }, frames, efunc).then(function () {
        return _this4.emit('crop.change');
      });
    }
  }, {
    key: "createMover",
    value: function createMover() {
      var _this5 = this;
      var w, h;
      this.pos = Rect.from(this.el);
      var stick;
      Dragger(this.el, function () {
        var pe = _this5.el.parentElement;
        if (!_this5.stage.enabled) return false;
        var _ref = [pe.offsetWidth, pe.offsetHeight];
        w = _ref[0];
        h = _ref[1];
        stick = Rect.from(_this5.el);
        _this5.el.focus();
        _this5.stage.activate(_this5);
        return true;
      }, function (x, y) {
        _this5.pos.x = stick.x + x;
        _this5.pos.y = stick.y + y;
        _this5.render(_this5.pos.rebound(w, h));
      }, function () {
        _this5.emit('crop.change');
      });
    }
  }, {
    key: "nudge",
    value: function nudge() {
      var x = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 0;
      var y = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
      var pe = this.el.parentElement;
      var _ref2 = [pe.offsetWidth, pe.offsetHeight],
        w = _ref2[0],
        h = _ref2[1];
      if (x) this.pos.x += x;
      if (y) this.pos.y += y;
      this.render(this.pos.rebound(w, h));
      this.emit('crop.change');
    }
  }, {
    key: "createHandles",
    value: function createHandles() {
      var _this6 = this;
      this.options.handles.forEach(function (c) {
        var handle = Handle.create('jcrop-handle ' + c);
        handle.appendTo(_this6.el);
        var stick;
        Dragger(handle.el, function () {
          if (!_this6.stage.enabled) return false;
          var pe = _this6.el.parentElement;
          var w = pe.offsetWidth;
          var h = pe.offsetHeight;
          stick = Sticker.create(Rect.from(_this6.el), w, h, c);
          if (_this6.aspect) stick.aspect = _this6.aspect;
          _this6.el.focus();
          _this6.emit('crop.active');
          return true;
        }, function (x, y) {
          return _this6.render(stick.move(x, y));
        }, function () {
          _this6.emit('crop.change');
        });
      });
      return this;
    }
  }, {
    key: "isActive",
    value: function isActive() {
      return this.stage && this.stage.active === this;
    }
  }, {
    key: "render",
    value: function render(r) {
      r = r || this.pos;
      this.el.style.top = Math.round(r.y) + 'px';
      this.el.style.left = Math.round(r.x) + 'px';
      this.el.style.width = Math.round(r.w) + 'px';
      this.el.style.height = Math.round(r.h) + 'px';
      this.pos = r;
      this.emit('crop.update');
      return this;
    }
  }, {
    key: "doneDragging",
    value: function doneDragging() {
      this.pos = Rect.from(this.el);
    }
  }]);
  return Widget;
}(ConfObj);
Widget.create = function () {
  var options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var el = document.createElement('div');
  var opts = extend({}, Defaults, options);
  el.setAttribute('tabindex', '0');
  el.className = opts.cropperClass || 'jcrop-widget';
  return new (options.widgetConstructor || Widget)(el, opts);
};
export default Widget;
